<?php
// $Id: inkribbon.drush.inc,v 1.14.2.8 2010/06/27 12:08:12 mverbaar Exp $

/**
 * Implementation of hook_drush_command().
 */
function inkribbon_drush_command() {
  $items = array();

  $items['inkribbon'] = array(
    'description' => 'Create a new Ink Ribbon sub theme.',
    'arguments' => array(
      'name' => 'The name for your sub theme.',
      'machine_name' => '[optional] A machine-readable name for your sub theme.',
    ),
    'examples' => array(
      'drush ink "My awesome sub theme"',
    ),
    'aliases' => array('ink'),
  );

  return $items;
}

/**
 * Command: create a new Ink Ribbon sub theme.
 */
function drush_inkribbon($name = 'My theme', $machine_name = '') {
  $machine_name = ($machine_name) ? $machine_name : preg_replace('/[^a-z0-9]+/', '', strtolower($name));
  $inkribbon_path = drush_locate_root() . '/' . drupal_get_path('theme', 'inkribbon');

  $subtheme_path = split('/', $inkribbon_path);
  array_pop($subtheme_path);
  $subtheme_path = join('/', $subtheme_path) . '/' . $machine_name;

  // Make a fresh copy of the starter kit and rename things where applicable.
  drush_op('inkribbon_copy', $inkribbon_path . '/STARTERKIT', $subtheme_path, '/^(\.(\.)?|CVS|SVN|\.DS_Store)$/');
  drush_op('inkribbon_file_str_replace', $subtheme_path . '/STARTERKIT.info.txt', 'name = STARTERKIT', 'name = ' . $name);
  drush_op('rename', $subtheme_path . '/STARTERKIT.info.txt', $subtheme_path . '/' . $machine_name . '.info');

  // Notify user of the newly created theme.
  drush_print(dt('Theme !name created in !path.',
    array(
      '!name' => $name,
      '!path' => $subtheme_path,
    )));
}

/**
 * Copy a directory recursively.
 *
 * @param $source
 *   Path to source directory.
 * @param $target
 *   Path to target directory.
 * @param $ignore
 *   Regex pattern for files to ignore.
 */
function inkribbon_copy($source, $target, $ignore = '/^\.(\.)?$/') {
  if (!is_dir($source)) {
    drush_die(dt('The directory !directory was not found.', array('!directory' => $source)));
  }
  $dir = opendir($source);
  @mkdir($target);
  while($file = readdir($dir)) {
    if (!preg_match($ignore, $file)) {
      if (is_dir($source . '/' . $file)) {
        inkribbon_copy($source . '/' . $file, $target . '/' . $file, $ignore);
      }
      else {
        copy($source . '/' . $file, $target . '/' . $file);
      }
    }
  }
  closedir($dir);
}

/**
 * Replace strings in file contents.
 *
 * @param $file_path
 * @param $find
 * @param $replace
 */
function inkribbon_file_str_replace($file_path, $find, $replace) {
  $file_contents = file_get_contents($file_path);
  $file_contents = str_replace($find, $replace, $file_contents);
  file_put_contents($file_path, $file_contents);
}
